==> template-engine-0.0.1.tgz: package/lib/driver/DriverRemote.js <==
var Class          = require("core").Class;
var Event          = require('core').Event.Event;
var ErrorEvent     = require('core').Event.ErrorEvent;
var Loader         = require('core').Net.Loader;
var OpalLoader     = require('core').Opal.OpalLoader;
var OpalRequest    = require('core').Opal.OpalRequest;
var DriverAbstract = require('./DriverAbstract.js').DriverAbstract;


/**
 * Implementation of driver which making remote calls through OPAL intraface.
 * Dispatches event: DriverAbstract.LOADED on successfull data retrieving otherwise dispatches DriverAbstract.ERROR
 * @class DriverRemote class
 * @extends DriverAbstract
 * @requires Class 
 * @requires DriverAbstract 
 * @requires OpalLoader 
 * @requires OpalRequest 
 * @requires Event 
 * @requires ErrorEvent
 * @param {Object} params Parameters which will be passed to OPAL call.
 */
var DriverRemote = function(){

    /** @ignore */
    this.Extends = DriverAbstract;
    
    /**
     * @property
     * @private
     */
    this._params = null;
    
    /**
     * @property
     * @private
     */
    this._loader = null;
    
    /** @ignore */
    this.initialize = function(params){
        if(!params || typeof params != "object" || params.constructor != Object){
            throw DriverRemote.Exception.WRONG_PARAMS;
        }
        this._params = params;
        this._loader = new OpalLoader();
    };

    /**
     * Makes remote call through OPAL interface. Implements DriverAbstract interface.
     * @public
     * @throws {DriverRemote.Exception.OPAL_WRONG_PARAMS} if given params are invalid for OPAL (see:{@link OpalRequest})
     */
    this.load = function(){
        try{
            var opalRequest = new OpalRequest(this._params);            
        }catch(e){
            throw DriverRemote.Exception.OPAL_WRONG_PARAMS;
        }
        
        //FIXME: do wywalenia
        opalRequest.setHost('rtx.m4r2.onet');
        
        this._loader.addEventListener(OpalLoader.Event.JSON_RESPONSE, this._onJsonResponse, this);
        this._loader.addEventListener(OpalLoader.Event.HTTP_RESPONSE, this._onHttpResponse, this);
        this._loader.addEventListener(Loader.ERROR, this._onError, this);

        this._loader.load(opalRequest);
    };

    /**
     * @private
     */
    this._onJsonResponse = function(e){
        this.dispatchEvent(new Event(DriverAbstract.LOADED, e.data.getBody()));
    };
    
    /**
     * @private
     */
    this._onHttpResponse = function(e){
        console.log(e);
        //TODO dodac sprawdzanie typu bledu i nadawanie kodu i msg dla emitowanego ErrorEvent
        //FIXME to wogole jest "popsute" bo nie przekazuje bledu z opala dalej
        this.dispatchEvent(new ErrorEvent(DriverAbstract.ERROR, e.data));
    };

    /**
     * @private
     */
    this._onError = function(e){
        console.log(e);
        //TODO dodac sprawdzanie typu bledu i nadawanie kodu i msg dla emitowanego ErrorEvent
        //FIXME to wogole jest "popsute" bo nie przekazuje bledu z opala dalej
        this.dispatchEvent(new ErrorEvent(DriverAbstract.ERROR, e.data));
    };
};

DriverRemote = new Class(new DriverRemote());
/**
 * Namespace for exeptions messages.
 * @constant
 * @static
 * @namespace
 */
DriverRemote.Exception = {};
/**
 * @constant
 * @static
 */
DriverRemote.Exception.WRONG_PARAMS = 'Given param has to be an object';
/**
 * @static
 * @constant
 */
DriverRemote.Exception.OPAL_WRONG_PARAMS = 'Given configuration is not valid';

exports.DriverRemote = DriverRemote;

==> template-engine-0.0.4.tgz: package/lib/driver/DriverRemote.js <==
var Class          = require("core").Class;
var Event          = require('core').Event.Event;
var ErrorEvent     = require('core').Event.ErrorEvent;
var Loader         = require('core').Net.Loader;
var OpalLoader     = require('core').Opal.OpalLoader;
var OpalRequest    = require('core').Opal.OpalRequest;
var DriverAbstract = require('./DriverAbstract.js').DriverAbstract;


/**
 * Implementation of driver which making remote calls through OPAL intraface.
 * Dispatches event: DriverAbstract.LOADED on successfull data retrieving otherwise dispatches DriverAbstract.ERROR
 * @class DriverRemote class
 * @extends DriverAbstract
 * @requires Class 
 * @requires DriverAbstract 
 * @requires OpalLoader 
 * @requires OpalRequest 
 * @requires Event 
 * @requires ErrorEvent
 * @param {Object} params Parameters which will be passed to OPAL call.
 */
var DriverRemote = function(){

    /** @ignore */
    this.Extends = DriverAbstract;
    
    /**
     * @property
     * @private
     */
    this._params = null;
    
    /**
     * @property
     * @private
     */
    this._loader = null;
    
    /** @ignore */
    this.initialize = function(params){
        if(!params || typeof params != "object" || params.constructor != Object){
            throw DriverRemote.Exception.WRONG_PARAMS;
        }
        this._params = params;
        this._loader = new OpalLoader();
    };

    /**
     * Makes remote call through OPAL interface. Implements DriverAbstract interface.
     * @public
     * @throws {DriverRemote.Exception.OPAL_WRONG_PARAMS} if given params are invalid for OPAL (see:{@link OpalRequest})
     */
    this.load = function(){
        try{
            var opalRequest = new OpalRequest(this._params);            
        }catch(e){
            throw DriverRemote.Exception.OPAL_WRONG_PARAMS;
        }
        
        // mozliwosc nadpisania gateway opala
        if(this._params.gateway){
            opalRequest.setHost(this._params.gateway.host);
            opalRequest.setPort(this._params.gateway.port);
        }
        
        this._loader.addEventListener(OpalLoader.Event.JSON_RESPONSE, this._onJsonResponse, this);
        this._loader.addEventListener(OpalLoader.Event.HTTP_RESPONSE, this._onHttpResponse, this);
        this._loader.addEventListener(Loader.ERROR, this._onError, this);

        this._loader.load(opalRequest);
    };

    /**
     * @private
     */
    this._onJsonResponse = function(e){
        this.dispatchEvent(new Event(DriverAbstract.LOADED, e.data.getBody()));
    };
    
    /**
     * @private
     */
    this._onHttpResponse = function(e){
        console.log(e);
        //TODO dodac sprawdzanie typu bledu i nadawanie kodu i msg dla emitowanego ErrorEvent
        //FIXME to wogole jest "popsute" bo nie przekazuje bledu z opala dalej
        this.dispatchEvent(new ErrorEvent(DriverAbstract.ERROR, e.data));
    };

    /**
     * @private
     */
    this._onError = function(e){
        console.log(e);
        //TODO dodac sprawdzanie typu bledu i nadawanie kodu i msg dla emitowanego ErrorEvent
        //FIXME to wogole jest "popsute" bo nie przekazuje bledu z opala dalej
        this.dispatchEvent(new ErrorEvent(DriverAbstract.ERROR, e.data));
    };
};

DriverRemote = new Class(new DriverRemote());
/**
 * Namespace for exeptions messages.
 * @constant
 * @static
 * @namespace
 */
DriverRemote.Exception = {};
/**
 * @constant
 * @static
 */
DriverRemote.Exception.WRONG_PARAMS = 'Given param has to be an object';
/**
 * @static
 * @constant
 */
DriverRemote.Exception.OPAL_WRONG_PARAMS = 'Given configuration is not valid';

exports.DriverRemote = DriverRemote;
